@@ -4,7 +4,7 @@ import threading
 
 
 class Database():
-    def __init__(self, name, waiters, executors, engine=None, operational_error=None):
+    def __init__(self, name, waiters, executors, engine=None, operational_error=None,load_balancer=None):
         self.name = name
         self.status = DatabaseStatus.RUNNING.value
         self.status_lock = threading.Lock()
@@ -17,6 +17,9 @@ class Database():
         self.engine = engine
         self.operational_error = operational_error
         self.info = queue.Queue(1)
+        self.load_balancer=load_balancer
+        self.r_query_succeeded_value=False
+        self.r_query_ended=threading.Event()
 
     def run_queries(self):
         while self.has_queries.acquire():
