@@ -1,37 +1,31 @@
+import abc
 import inspect
 from datetime import datetime
 
 import django.db
 import django.db.models
 
+from .query import QueryType
 
-class Executor():
-    def __init__(self, result=None):
-        self._result = result
 
+class Executor(abc.ABC):
+    @abc.abstractmethod
     def run_query(self, query, database):
         pass
 
 
-class NoQuerySetExecutor(Executor):
+class QueryExecutor(Executor):
     def run_query(self, query, database):
         if query.method == 'get_queryset':
             instance = query.model.loadbalancer_base_manager
             result = instance.__getattribute__(query.method)(*query.args, **query.kwargs).using(database.name)
-        else:
+        elif query.type == QueryType.NO_QUERYSET.value:
             instance = query.model
             result = dict(inspect.getmembers(django.db.models.Model))[query.method](instance, using=database.name)
-        self._result.put({query.query_id: result})
-        now = datetime.now()
-        current_time = now.strftime("%H:%M:%S")
-        print(f"{current_time}   {database.name}   {query.model}   {query.method}")
-
-
-class QuerySetExecutor(Executor):
-    def run_query(self, query, database):
-        instance = query.model.models_manager.using(database.name)
-        result = instance.__getattribute__(query.method)(*query.args, **query.kwargs)
-        self._result.put({query.query_id: result})
+        else:
+            instance = query.model.models_manager.using(database.name)
+            result = instance.__getattribute__(query.method)(*query.args, **query.kwargs)
+        database.load_balancer.end_query(query, result)
         now = datetime.now()
         current_time = now.strftime("%H:%M:%S")
         print(f"{current_time}   {database.name}   {query.model}   {query.method}")
