@@ -1,4 +1,3 @@
-import queue
 import sqlite3
 import threading
 
@@ -10,7 +9,7 @@ from .balancing_algorithms.cud_algorithms.multithreading import \
 from .balancing_algorithms.r_algorithms.interval import Interval
 from .balancing_algorithms.r_algorithms.round_robin import RoundRobin
 from .database import Database, DatabaseEngine
-from .executor import QuerySetExecutor, NoQuerySetExecutor
+from .executor import QueryExecutor
 from .info_query_executor import ResponseTimeExecutor, NumberOfConnectionsExecutor
 from .load_balancer import LoadBalancer
 from .local_settings import LOAD_BALANCER, DATABASES
@@ -22,24 +21,25 @@ from .watch_dog import WatchDog
 class LoadBalancerFactory:
     @classmethod
     def create_load_balancer(cls):
-        result = queue.Queue()
-        databases = cls._create_databases(result)
+        databases = cls._create_databases()
         watch_dog = WatchDog(databases, LOAD_BALANCER['WAIT_TIME'])
         watch_dog_thread = threading.Thread(target=watch_dog.check_databases_statuses, args=(), daemon=True)
         watch_dog_thread.start()
         cud_algorithm = cls._create_cud_algorithm(databases)
         r_algorithm = cls._create_r_algorithm(databases)
-        return LoadBalancer(result, databases, cud_algorithm, r_algorithm)
+        load_balancer = LoadBalancer(databases, cud_algorithm, r_algorithm)
+        for database in databases:
+            database._load_balancer = load_balancer
+        return load_balancer
 
     @classmethod
-    def _create_databases(cls, result):
+    def _create_databases(cls):
         if LOAD_BALANCER['CUD_ALGORITHM'] == "MULTITHREADING":
             databases = []
             for i, name in enumerate(LOAD_BALANCER['DATABASES']):
                 database = Database(name, {Wait.WAIT.value: WaitWaiter(),
                                            Wait.DONT_WAIT.value: DontWaitWaiter()},
-                                    {QueryType.QUERYSET.value: QuerySetExecutor(result),
-                                     QueryType.NO_QUERYSET.value: NoQuerySetExecutor(result)},
+                                    {QueryType.QUERYSET.value: QueryExecutor()},
                                     DATABASES[name]['ENGINE'],
                                     cls.OperationalErrorGenerator.generate_operational_error(DATABASES[name]['ENGINE']))
                 databases.append(database)
@@ -60,7 +60,7 @@ class LoadBalancerFactory:
         elif LOAD_BALANCER['R_ALGORITHM']['NAME'] == "INTERVAL_TIME":
             algorithm = Interval(databases)
             for database in databases:
-                database.executors[QueryType.INFO_RESPONSE_TIME] = ResponseTimeExecutor()
+                database.executors[QueryType.INFO_RESPONSE_TIME.value] = ResponseTimeExecutor()
             threading.Thread(target=algorithm.update_info,
                              args=(LOAD_BALANCER['R_ALGORITHM']['INTERVAL'], QueryType.INFO_RESPONSE_TIME.value),
                              daemon=True).start()
@@ -68,10 +68,10 @@ class LoadBalancerFactory:
         elif LOAD_BALANCER['R_ALGORITHM']['NAME'] == "INTERVAL_NUMBER_OF_CONNECTIONS":
             algorithm = Interval(databases)
             for database in databases:
-                database.executors[QueryType.INFO_NUMBER_OF_CONNECTIONS] = NumberOfConnectionsExecutor()
+                database.executors[QueryType.INFO_NUMBER_OF_CONNECTIONS.value] = NumberOfConnectionsExecutor()
             threading.Thread(target=algorithm.update_info,
                              args=(
-                             LOAD_BALANCER['R_ALGORITHM']['INTERVAL'], QueryType.INFO_NUMBER_OF_CONNECTIONS.value),
+                                 LOAD_BALANCER['R_ALGORITHM']['INTERVAL'], QueryType.INFO_NUMBER_OF_CONNECTIONS.value),
                              daemon=True).start()
             return algorithm
 
