@@ -35,10 +35,18 @@ class WaitWaiter(Waiter):
 
 class DontWaitWaiter(Waiter):
     def run_query(self, query, database):
-        try:
-            self.executor.run_query(query, database)
+        if database.check_status() == DatabaseStatus.RUNNING.value:
+            try:
+                self.executor.run_query(query, database)
+                database.query_ended.set()
+                database.r_query.succeeded = True
+                database.r_query_ended.set()
+            except django.db.utils.OperationalError:
+                database.change_status(DatabaseStatus.DOWN.value)
+                database.query_ended.set()
+                database.r_query.succeeded = False
+                database.r_query_ended.set()
+        else:
             database.query_ended.set()
-        except django.db.utils.OperationalError:
-            database.change_status(DatabaseStatus.DOWN.value)
-            database.query_ended.set()
-            raise django.db.utils.OperationalError
+            database.r_query.succeeded=False
+            database.r_query_ended.set()
\ No newline at end of file
